@@ -4,14 +4,14 @@ context("Orphaned")
 test_that("Orphaned figures are found", {
   skip_old_freetype()
 
-  orphaned <- filter_cases(mock_cases, "case_orphaned")
-  expect_equal(map_chr(orphaned, "name"), set_names(c("orphaned1", "orphaned2")))
+  orphaned <- filter_cases(mock_cases, "orphaned_case")
+  expect_equal(map_chr(unname(orphaned), "name"), c("orphaned1", "orphaned2"))
 })
 
 test_that("Orphaned files are found and deleted", {
   skip_old_freetype()
 
-  orphaned <- filter_cases(mock_cases, "case_orphaned")
+  orphaned <- filter_cases(mock_cases, "orphaned_case")
   files <- map_chr(orphaned, "path")
   files <- map_chr(files, purrr::partial(file.path, mock_pkg_dir, "tests", "testthat"))
   files_exist <- purrr::every(files, file.exists)
